==> android-3.1.0-sources.jar: com/virgilsecurity/sdk/crypto/utils/ConversionUtils.java <==
/*
 * Copyright (c) 2016, Virgil Security, Inc.
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * * Neither the name of virgil nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.virgilsecurity.sdk.crypto.utils;

import com.virgilsecurity.sdk.crypto.Base64;

/**
 * Provides convert functionalities.
 *
 * @author Andrii Iakovenko
 *
 */
public class ConversionUtils {

	/**
	 * Convert string to base64-encoded string.
	 * 
	 * @param value
	 *            The string to be encoded.
	 * @return Base64-encoded string.
	 */
	public static String toBase64String(String value) {
		if (value == null) {
			return null;
		}
		return Base64.encode(value.getBytes());
	}

	/**
	 * Decode base64-encoded string and return result as string.
	 * 
	 * @param base64String
	 *            The string to be decoded.
	 * @return Decoded string.
	 */
	public static String fromBase64String(String base64String) {
		if (base64String == null) {
			return null;
		}
		return new String(Base64.decode(base64String));
	}

}

==> android-3.2.3-sources.jar: com/virgilsecurity/sdk/crypto/utils/ConversionUtils.java <==
/*
 * Copyright (c) 2016, Virgil Security, Inc.
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * * Neither the name of virgil nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.virgilsecurity.sdk.crypto.utils;

import com.virgilsecurity.sdk.crypto.Base64;

/**
 * Provides convert functionalities.
 *
 * @author Andrii Iakovenko
 *
 */
public class ConversionUtils {

	/**
	 * Convert string to base64-encoded string.
	 * 
	 * @param value
	 *            The string to be encoded.
	 * @return Base64-encoded string.
	 */
	public static String toBase64String(String value) {
		if (value == null) {
			return null;
		}
		return Base64.encode(value.getBytes());
	}

	/**
	 * Convert byte array to base4-encoded string.
	 * 
	 * @param data
	 *            The data to be encoded.
	 * @return Base64-encoded string.
	 */
	public static String toBase64String(byte[] data) {
		if (data == null) {
			return null;
		}
		return Base64.encode(data);
	}

	/**
	 * Decode base64-encoded string and return result as string.
	 * 
	 * @param base64String
	 *            The string to be decoded.
	 * @return Decoded string.
	 */
	public static String fromBase64String(String base64String) {
		if (base64String == null) {
			return null;
		}
		return new String(Base64.decode(base64String));
	}

}
